# [フロントエンド]の要件定義書
## ゴール: {prompt}
上記を満たすフロントエンドの要件を記述する
# [システム名]の要件定義書
## ゴール: {prompt}
上記を満たす要件定義書を作成してください。

オブジェクト指向の原則に従って、以下の要件を含めて要件定義書を作成してください。

## 1. 目的
システムの全体的な目的を簡潔に説明してください。

## 2. ファイル・フォルダ構成
- Markdown形式で省略なしのファイル・フォルダ構成
